//add event listener for cordova
document.addEventListener("deviceready", onDeviceReady, false);
var db, db_version;

function onDeviceReady() {
    db = window.openDatabase("GradeBlade", "", "GradeBlade", 10000000);
    db_version = db.version;

    //update version
    if (db_version != 2.2) {
        db.changeVersion(db_version, "2.2", function () {console.log('we changed the version :)')});
    }
    //create tables if needed
    db.transaction(function(tx) {
        tx.executeSql('CREATE TABLE IF NOT EXISTS SEMESTERS (semester_id INTEGER PRIMARY KEY, name TEXT, year INTEGER)');
        tx.executeSql('CREATE TABLE IF NOT EXISTS CLASSES (class_id INTEGER PRIMARY KEY, parent_semester INTEGER, name TEXT)');
        tx.executeSql('CREATE TABLE IF NOT EXISTS CATEGORIES (category_id INTEGER PRIMARY KEY, parent_class INTEGER, name TEXT, earned FLOAT, total FLOAT, weight FLOAT, data TEXT, isExtraCredit INTEGER DEFAULT 0)');
    }, function(err){console.log(err)}, function () {
        db.transaction(function(tx){
            tx.executeSql('ALTER TABLE CATEGORIES ADD isExtraCredit INTEGER DEFAULT 0');
        }, function(err){console.log(JSON.stringify(err))}, function(t,r){console.log('added the new column')});
    });
}

// Ionic Starter App

// angular.module is a global place for creating, registering and retrieving Angular modules
// 'starter' is the name of this angular module example (also set in a <body> attribute in index.html)
// the 2nd parameter is an array of 'requires'
// 'starter.services' is found in services.js
// 'starter.controllers' is found in controllers.js
angular.module('starter', ['ionic', 'starter.controllers', 'starter.services'])

.run(function($ionicPlatform, AdMob, FileService, IAP, DBackUp, Settings) {
    $ionicPlatform.ready(function() {
        // Hide the accessory bar by default (remove this to show the accessory bar above the keyboard
        // for form inputs)
        if (window.cordova && window.cordova.plugins.Keyboard) {
            cordova.plugins.Keyboard.hideKeyboardAccessoryBar(false);
        }
        //statusbar
        if (window.StatusBar) {
            // org.apache.cordova.statusbar required
            StatusBar.styleDefault();
        }
		
		DBackUp.turnOnBackUps(Settings.useAutoBackups());
		
		//IAP.load();
		

        //init the ad
        //AdMob.init();
        //create the add
        //AdMob.create();

		//create the database back up folder and file
        FileService.checkDir('GradeBlade').then(function(){
            console.log('already made the dir :)');
			/*
            FileService.removeDir('GradeBlade').then(function () {
                console.log('i removed the dir like a boss');
            }, function () {
                console.log('failed removing the dir');
            });*/
        }, function () {
            console.log('does not exist');
            FileService.createDir('GradeBlade').then(function() {
                console.log('made the dir');
                FileService.createFile('GradeBlade', 'dbbackup.json').then(function () {
                    console.log('made the file');
                });
            });
        });
		
    });
})

.config(function($stateProvider, $urlRouterProvider) {

    // Ionic uses AngularUI Router which uses the concept of states
    // Learn more here: https://github.com/angular-ui/ui-router
    // Set up the various states which the app can be in.
    // Each state's controller can be found in controllers.js
    $stateProvider

    // setup an abstract state for the tabs directive
        .state('app', {
        url: "/app",
        abstract: true,
        templateUrl: "templates/tabs.html"
    })

    // Each tab has its own nav history stack:

    .state('app.gradebook', {
        url: '/gradebook',
        views: {
            'tab-gradebook': {
                templateUrl: 'templates/gradebook.html',
                controller: 'GradebookCtrl',
                resolve: {
                    Semesters: function(Semester) {
                        return Semester.loadSemesters().then(function(s){
							return s;
						}, function (fail){
							console.log(fail);
							return {};
						});
                    }
                }
            }
        }
    })

    .state('app.class-list', {
        url: '/class-list/:semesterId/:semesterName/:semesterYear',
        views: {
            'tab-gradebook': {
                templateUrl: 'templates/class-list.html',
                controller: 'ClassCtrl',
                resolve: {
                    Classes: function(Class, $stateParams) {
                        return Class.loadClasses($stateParams.semesterId).then(function(c){
							return c;
						}, function (fail){
							console.log(fail);
							return [];
						});
                    }
                }
            }
        }
    })

    .state('app.class-detail', {
        url: '/class-detail/:classId/:className',
        views: {
            'tab-gradebook': {
                templateUrl: 'templates/class-detail.html',
                controller: 'CategoryCtrl',
                resolve: {
                    ClassInfo: function(Category, $stateParams, Grade) {
                        return Category.loadCats($stateParams.classId).then(function(cats){
							return Grade.getGrade($stateParams.classId).then(function(grade){
									return {'grade':grade, 'categories': cats};
							});
						}, function (error){
							console.log(error);
							return [];
						});
                    }
                }
            }
        }
    })

    .state('app.category-detail', {
        url: '/category-detail/:catId/:catName',
        views: {
            'tab-gradebook': {
                templateUrl: 'templates/category-detail.html',
                controller: 'singleCatCtrl',
                resolve: {
                    singleCategory: function(Category, $stateParams) {
                        return Category.loadSingleCat($stateParams.catId);
                    }
                }
            }
        }
    })
	
	.state('app.extra_credit', {
		url:'/extra_credit/:classId',
		views: {
			'tab-gradebook': {
				templateUrl: 'templates/extra_credit.html',
				controller: 'extraCreditCtrl',
				resolve: {
					extraCredit: function(Category, $stateParams) {
						return Category.loadExtraCredit($stateParams.classId).then(function(data){
                            return data;
                        }, function (err){
                            alert(JSON.stringify(err));
                        });
					}
				}
			}
		}
	})
	
	.state('app.points', {
		url:'/points/:catId/:catName',
		views: {
			'tab-gradebook': {
				templateUrl:'templates/points.html',
				controller: 'pointsCtrl',
				resolve: {
					Points: function(Category, $stateParams){
						return Category.loadSingleCat($stateParams.catId);
					}
				}
			}
		}
	})
	
	.state('app.iap', {
		url:'/iap',
		views: {
			'in-app-purchases': {
				templateUrl: 'templates/iap.html',
				controller: 'IAPCtrl'
			}
		}
	})

    .state('app.settings', {
        url: '/settings',
        views: {
            'tab-settings': {
                templateUrl: 'templates/settings.html',
                controller: 'SettingsCtrl'
            }
        }
    });

    // if none of the above states are matched, use this as the fallback
    $urlRouterProvider.otherwise('/app/gradebook');

});