angular.module('starter.services', [])

    .factory('AdMob', function () {
    // optional, in case respond to events
    function registerAdEvents() {
        document.addEventListener('onReceiveAd', function () {
            console.log('received add');
        });
        document.addEventListener('onFailedToReceiveAd', function (data) {
            console.log(data);
        });
        document.addEventListener('onPresentAd', function () {
            console.log('presenting add')
        });
        document.addEventListener('onDismissAd', function () {});
        document.addEventListener('onLeaveToAd', function () {});
        document.addEventListener('onReceiveInterstitialAd', function () {});
        document.addEventListener('onPresentInterstitialAd', function () {});
        document.addEventListener('onDismissInterstitialAd', function () {});
    };

    return {
        init: function () {

            //initialize app
            if (window.plugins && window.plugins.AdMob) {
                var ad_units = {
                    android: {
                        banner: 'ca-app-pub-3682141877454304/1233295875'
                    },
                    ios: {
                        banner: 'ca-app-pub-3682141877454304/1233295875'
                    }
                };
                var admobid;

                if (cordova.platform != 'iOS') {
                    admobid = ad_units.android;
                } else {
                    admobid = ad_units.ios;
                }

                window.plugins.AdMob.setOptions({
                    bannerId: admobid.banner,
                    bannerAtTop: false, // set to true, to put banner at top
                    overlap: false, // set to true, to allow banner overlap webview
                    offsetTopBar: false, // set to true to avoid ios7 status bar overlap
                    isTesting: false, // receiving test ad
                    autoShow: true // auto show interstitial ad when loaded
                });

                //register ad events
                registerAdEvents();

            } else {
                console.log('ad mob was not ready yet');
            }
        },
        create: function () {
            // display a banner at startup
            window.plugins.AdMob.createBannerView();
        }
    }
})

    .factory('Semester', function ($q) {
    var db = window.openDatabase("GradeBlade", "", "GradeBlade", 10000000);
    return {
        newSemester: function (name, array, year) {
            db.transaction(function (tx) {
                tx.executeSql('INSERT INTO SEMESTERS(name, year) VALUES (?,?)', [name, year], nullHandler, errorHandler);
            }, errorHandler, function () {
                db.transaction(function (tx) {
                    tx.executeSql('SELECT * FROM SEMESTERS WHERE semester_id = (SELECT MAX(semester_id) FROM SEMESTERS)', [], function (t, r) {
                        if (r) {
                            var list = [];
                            for (var i = 0; i < r.rows.length; i++) {
                                var rowobj = r.rows.item(i);
                                var obj = {
                                    'name': rowobj.name,
                                        'year': rowobj.year,
                                        'id': rowobj.semester_id
                                };
                                list.push(obj);
                            }

                            var semestersLength = list.length;
                            var firstLetter;

                            for (var j = 0; j < semestersLength; j++) {
                                var item = list[j];
                                var firstLetter = item.year;

                                if (!array[firstLetter]) {
                                    array[firstLetter] = [];
                                }

                                var obj = {
                                    'year': item.year,
                                        'name': item.name,
                                        'id': item.id
                                };

                                array[firstLetter].push(obj);
                            }
                        }
                    }, errorHandler);
                });
            });
        },

        deleteSemester: function (id) {
            db.transaction(function (tx) {
                tx.executeSql('DELETE FROM SEMESTERS WHERE semester_id = ?', [id], nullHandler, errorHandler);
                //grab all the classes
                tx.executeSql('SELECT * FROM CLASSES WHERE parent_semester = ?', [id], function (t, r) {
                    if (r) {
                        for (var i = 0; i < r.rows.length; i++) {
                            var rowobj = r.rows.item(i);
                            var id = rowobj.class_id;
                            //for each class delete all of it's cats
                            var remove_cat = function (parent) {
                                db.transaction(function (tx) {
                                    tx.executeSql('DELETE FROM CATEGORIES WHERE parent_class = ?', [parent], nullHandler, errorHandler);
                                });
                            }(id);
                        }
                    }
                }, errorHandler);
                //delete all cats
                tx.executeSql('DELETE FROM CLASSES WHERE parent_semester = ?', [id], nullHandler, errorHandler);
            });
        },

        loadSemesters: function () {
            var deferred = $q.defer();
            db.transaction(function (tx) {
                tx.executeSql('SELECT * FROM SEMESTERS ORDER BY year ASC', [], function (t, r) {
                    if (r) {
                        var list = [];
                        var array = {};
                        for (var i = 0; i < r.rows.length; i++) {
                            var rowobj = r.rows.item(i);
                            var obj = {
                                'name': rowobj.name,
                                    'year': rowobj.year,
                                    'id': rowobj.semester_id
                            };
                            list.push(obj);
                        }

                        var semestersLength = list.length;
                        var firstLetter;

                        for (var j = 0; j < semestersLength; j++) {
                            var item = list[j];
                            var firstLetter = item.year;

                            if (!array[firstLetter]) {
                                array[firstLetter] = [];
                            }

                            var obj2 = {
                                'year': item.year,
                                    'name': item.name,
                                    'id': item.id
                            };

                            array[firstLetter].push(obj2);
                        }

                        deferred.resolve(array);
                    } else {
                        deferred.reject("Error loading the data!");
                    }
                }, function (tx, error) {
                    deferred.reject(error);
                });
            }, function () {
                deferred.reject("Error loading the data!");
            });
            return deferred.promise;
        }
    }
})

    .factory('Class', function ($q) {
    var db = window.openDatabase("GradeBlade", "", "GradeBlade", 10000000);
    return {
        newClass: function (name, parent, array) {
            db.transaction(function (tx) {
                tx.executeSql('INSERT INTO CLASSES(name, parent_semester) VALUES(?, ?)', [name, parent], nullHandler, errorHandler);
            }, errorHandler, function () {
                db.transaction(function (tx) {
                    tx.executeSql('SELECT * FROM CLASSES WHERE class_id = (SELECT MAX(class_id) FROM CLASSES)', [], function (t, r) {
                        if (r) {
                            for (var i = 0; i < r.rows.length; i++) {
                                var rowobj = r.rows.item(i);
                                var name = rowobj.name;
                                var id = rowobj.class_id;
                                var parent = rowobj.parent_semester;
                                var obj = {
                                    'name': name,
                                        'id': id,
                                        'semester_id': parent
                                };
                                array.push(obj);
                            }
                        }
                    }, errorHandler);
                });
            });
        },

        deleteClass: function (id) {
            db.transaction(function (tx) {
                tx.executeSql('DELETE FROM CLASSES WHERE class_id = ?', [id], nullHandler, errorHandler);
                tx.executeSql('DELETE FROM CATEGORIES WHERE parent_class = ?', [id], nullHandler, errorHandler);
            });
        },

        loadClasses: function (id) {
            var deferred = $q.defer();
            db.transaction(function (tx) {
                tx.executeSql('SELECT * FROM CLASSES WHERE parent_semester = ? ORDER BY name ASC', [id], function (t, r) {
                    if (r) {
                        var array = [];
                        for (var i = 0; i < r.rows.length; i++) {
                            var rowobj = r.rows.item(i);
                            var obj = {
                                'name': rowobj.name,
                                    'id': rowobj.class_id,
                                    'semester_id': rowobj.parent_semester
                            };

                            array.push(obj);
                        }

                        deferred.resolve(array);
                    } else {
                        deferred.reject("Error loading data!");
                    }
                }, function (tx, error) {
                    deferred.reject(error);
                });
            }, function () {
                deferred.reject("Error loading data!");
            });
            return deferred.promise;
        },

        updateName: function (id, name, year) {
            db.transaction(function (tx) {
                tx.executeSql('UPDATE SEMESTERS SET name = ?, year = ? WHERE semester_id = ?', [name, year, id], nullHandler, errorHandler);
            });
        }
    }
})

    .factory('Category', function ($q) {
    var db = window.openDatabase("GradeBlade", "", "GradeBlade", 10000000);
    return {
        newCat: function (cat, parent_class, array, $location, $timeout) {
            db.transaction(function (tx) {
                tx.executeSql('INSERT INTO CATEGORIES(name, weight, isExtraCredit, parent_class) VALUES(?, ?, ?, ?)', [cat.name, cat.weight, cat.checked, parent_class], nullHandler, errorHandler);
            }, errorHandler, function () {
                db.transaction(function (tx) {
                        tx.executeSql('SELECT * FROM CATEGORIES WHERE category_id = (SELECT MAX(category_id) FROM CATEGORIES)', [], function (t, r) {
                            if (r) {
								if(cat.checked == 0){
									for (var i = 0; i < r.rows.length; i++) {
										var rowobj = r.rows.item(i);
										var obj = {
											'name': rowobj.name,
                                            'y': rowobj.weight,
                                            'cat_id': rowobj.category_id
										};

										array.push(obj);

										$timeout(function () {
											$location.path('/app/category-detail/' + rowobj.category_id + '/' + rowobj.name);
										});
									}
								} else {
									for(var j = 0; j< r.rows.length; j++){
										var rowobj = r.rows.item(j);
										var category = {};
										category.name = rowobj.name;
										category.id = rowobj.category_id;
										category.isExtraCredit = parseInt(rowobj.isExtraCredit) == 0 ? false : true;
										category.weight = rowobj.weight;
										category.earned = rowobj.earned || 0;
										category.total = rowobj.total || 0;
										category.data = JSON.parse(rowobj.data) || [];
										array.push(category);
									}
								}
                            }
                        }, errorHandler);
                });
            });
        },

        deleteCat: function (id) {
            db.transaction(function (tx) {
                tx.executeSql('DELETE FROM CATEGORIES WHERE category_id = ?', [id], nullHandler, errorHandler);
            });
        },

        loadSingleCat: function (id) {
            var deferred = $q.defer();
            db.transaction(function (tx) {
                tx.executeSql('SELECT * FROM CATEGORIES WHERE category_id = ?', [id], function (t, r) {
                    if (r) {
                        var category = {};
                        for (var i = 0; i < r.rows.length; i++) {
                            var rowobj = r.rows.item(i);
                            category.name = rowobj.name;
                            category.isExtraCredit = parseInt(rowobj.isExtraCredit) == 0 ? false : true;
                            category.weight = rowobj.weight;
                            category.earned = rowobj.earned || 0;
                            category.total = rowobj.total || 0;
                            category.data = rowobj.data != null ? JSON.parse(rowobj.data) : [];
                        }

                        deferred.resolve(category);
                    } else {
                        deferred.reject("Error loading data!");
                    }
                }, function (tx, error) {
                    deferred.reject(error);
                });
            }, function () {
                deferred.reject("Error loading data!");
            });
            return deferred.promise;
        },

        loadCats: function (parent) {
            var deferred = $q.defer();
            db.transaction(function (tx) {
                tx.executeSql('SELECT * FROM CATEGORIES WHERE parent_class = ? AND isExtraCredit = ?', [parent, 0], function (t, r) {
                    if (r) {
                        var array = [];
                        var weightTot = 0;
                        for (var i = 0; i < r.rows.length; i++) {
                            var rowobj = r.rows.item(i);
                            //skip adding any extra cred ones
                            var obj = {
                                'name': rowobj.name,
                                    'y': rowobj.weight,
                                    'cat_id': rowobj.category_id
                            };
                            weightTot += rowobj.weight;
                            array.push(obj);
                        }
                        if (weightTot < 100) {
                            array.push({
                                'name': 'Remaining',
                                    'y': 100 - weightTot,
                                    'cat_id': -1
                            });
                        }
                        deferred.resolve(array);
                    } else {
                        deferred.reject("Error loading data!");
                    }
                }, function (tx, error) {
                    deferred.reject(error);
                });
            }, function () {
                deferred.reject("Error loading data!");
            });
            return deferred.promise;
        },


        loadExtraCredit: function (parent) {
            var deferred = $q.defer();
            db.transaction(function (tx) {
                tx.executeSql('SELECT * FROM CATEGORIES WHERE parent_class = ? AND isExtraCredit = ?', [parent, 1], function (t, r) {
                    if (r) {
                        var array = [];
                        for (var i = 0; i < r.rows.length; i++) {
                            var rowobj = r.rows.item(i);
                            var category = {};
                            category.name = rowobj.name;
                            category.id = rowobj.category_id;
                            category.isExtraCredit = parseInt(rowobj.isExtraCredit) == 0 ? false : true;
                            category.weight = rowobj.weight;
                            category.earned = rowobj.earned || 0;
                            category.total = rowobj.total || 0;
                            category.data = rowobj.data != null ? JSON.parse(rowobj.data) : [];
                            array.push(category);
                        }
                        deferred.resolve(array);
                    } else {
                        deferred.reject("Error loading data in SQL execution!");
                    }
                }, function (error) {
                    deferred.reject(error);
                });
            }, function (err) {
                deferred.reject(err);
            }, function() {console.log('so we are here now??')});
            return deferred.promise;
        },

        //this updates the class name not the cat name
        updateName: function (id, name) {
            db.transaction(function (tx) {
                tx.executeSql('UPDATE CLASSES SET name = ? WHERE class_id = ?', [name, id], nullHandler, errorHandler);
            });
        },

        update: function (id, cat) {
            var deferred = $q.defer();
            var earned = 0;
            for (var i = 0; i < cat.data.length; i++) {
                earned += parseFloat(cat.data[i].earned) || 0;
            }
            db.transaction(function (tx) {
                tx.executeSql('UPDATE CATEGORIES SET name = ?, earned = ?, total = ?, weight = ?, data = ? WHERE category_id = ?', [cat.name, earned, cat.total, cat.weight, JSON.stringify(cat.data), id], nullHandler, function (t, e) {
                    deferred.reject(e);
                });
            }, function (t, e) {
                deferred.reject(e);
            }, function () {
                deferred.resolve();
            });

            return deferred.promise;
        }
    }
})

    .factory('Grade', function ($q) {
    return {
        getGrade: function (id) {
            var db = window.openDatabase("GradeBlade", "", "GradeBlade", 10000000);
            var deferred = $q.defer();

            db.transaction(function (tx) {
                tx.executeSql('SELECT * FROM CATEGORIES WHERE parent_class = ?', [id], function (t, r) {
                    if (r) {
                        var grade = 0;
                        for (var i = 0; i < r.rows.length; i++) {
                            var rowobj = r.rows.item(i);
                            var earned = rowobj.earned || 0;
                            var total = rowobj.total || 1;
                            if (total == 0) {
                                continue;
                            }
                            var weight = rowobj.weight / 100;
                            grade += weight * (earned / total);
                            console.log('earned: ' + earned + ' total: ' + total + ' weight: ' + weight);
                        }
                        deferred.resolve(grade * 100);
                    }
                }, function (tx, error) {
                    deferred.reject(error);
                });
            });
            return deferred.promise;
        }
    }
})

    .factory('Settings', function () {
    var db = window.openDatabase("GradeBlade", "", "GradeBlade", 10000000);
    return {
        setChartLabels: function (bool) {
            localStorage.setItem('chartLabels', bool);
        },

        useChartLabels: function () {
            return localStorage.getItem('chartLabels');
        },
        setPercentageLabels: function (bool) {
            localStorage.setItem('percentageLabels', bool);
        },

        usePercentageLabels: function () {
            return localStorage.getItem('percentageLabels');
        },
        useAutoBackups: function () {
            return (localStorage.getItem('autoBackUps') == 'true');
        },
        setAutoBackups: function (bool) {
            localStorage.setItem('autoBackUps', bool);
        },
        useHints: function () {
            //initially show them
            if (localStorage.getItem('hints') == null) {
                return true;
            }
            return (localStorage.getItem('hints') == 'true');
        },
        setHints: function (bool) {
            localStorage.setItem('hints', bool);
        },
        clear: function () {
            db.transaction(function (tx) {
                tx.executeSql('DROP TABLE IF EXISTS SEMESTERS', [], nullHandler, errorHandler);
                tx.executeSql('DROP TABLE IF EXISTS CLASSES', [], nullHandler, errorHandler);
                tx.executeSql('DROP TABLE IF EXISTS CATEGORIES', [], nullHandler, errorHandler);
            }, errorHandler, function () {
                navigator.notification.alert(
                    'Succesfully dropped all DB tables.',
                null,
                    'Winning!');
            });
        }
    }
})

    .factory('FileService', function ($q) {

    return {
        checkDir: function (dir) {
            var deferred = $q.defer();

            getFilesystem().then(

            function (filesystem) {
                filesystem.root.getDirectory(dir, {
                    create: false
                },

                function (dirEntry) {
                    //Dir exist
                    var dirPath = dirEntry.toURL();
                    deferred.resolve(dirPath);
                },

                function () {
                    //Dir dont exist
                    deferred.reject();
                });
            });

            return deferred.promise;
        },

        createDir: function (dir) {
            var deferred = $q.defer();

            getFilesystem().then(

            function (filesystem) {
                filesystem.root.getDirectory(dir, {
                    create: true
                }, function () {
                    deferred.resolve();
                });
            });

            return deferred.promise;
        },

        removeDir: function (dir) {
            var deferred = $q.defer();
            getFilesystem().then(

            function (filesystem) {
                filesystem.root.getDirectory(dir, {
                    create: false
                }, function (entry) {
                    entry.removeRecursively(function () {
                        deferred.resolve();
                    }, function () {
                        deferred.reject();
                    })
                })
            })
            return deferred.promise;
        },

        checkFile: function (dir, file) {
            var deferred = $q.defer();

            getFilesystem().then(

            function (filesystem) {
                filesystem.root.getFile('/' + dir + '/' + file, {
                    create: false
                },

                function (fileEntry) {
                    //File exist
                    deferred.resolve(fileEntry.toURL());
                },

                function () {
                    //File dont exist
                    deferred.reject();
                });
            });

            return deferred.promise;
        },

        createFile: function (dir, file) {
            var deferred = $q.defer();

            getFilesystem().then(

            function (filesystem) {
                filesystem.root.getFile('/' + dir + '/' + file, {
                    create: true
                }, function () {
                    deferred.resolve();
                });
            });
            return deferred.promise;
        },

        removeFile: function (dir, file) {
            var deferred = $q.defer();

            getFilesystem().then(

            function (filesystem) {
                filesystem.root.getFile('/' + dir + '/' + file, {
                    create: false
                }, function (fileEntry) {
                    fileEntry.remove(function () {
                        deferred.resolve();
                    });
                });
            });

            return deferred.promise;
        },

        writeFile: function (dir, file) {
            var deferred = $q.defer();

            getFilesystem().then(

            function (filesystem) {
                filesystem.root.getFile('/' + dir + '/' + file, {
                    create: false
                },

                function (fileEntry) {
                    fileEntry.createWriter(function (fileWriter) {
                        deferred.resolve(fileWriter);
                    });
                });
            });

            return deferred.promise;
        },

        readFile: function (dir, file) {
            var deferred = $q.defer();
            getFilesystem().then(

            function (filesystem) {
                filesystem.root.getFile('/' + dir + '/' + file, {
                    create: false
                },

                function (fileEntry) {
                    fileEntry.file(function (file) {
                        var reader = new FileReader();
                        reader.onloadend = function (evt) {
                            deferred.resolve(evt.target.result);
                        };

                        reader.readAsText(file);

                    });
                }, function () {
                    deferred.reject('could not find the file');
                });
            }, function () {
                deferred.reject('could not find the file');
            });

            return deferred.promise;
        }

    };

    function getFilesystem() {
        var deferred = $q.defer();

        window.requestFileSystem(LocalFileSystem.PERSISTENT, 0, function (filesystem) {
            deferred.resolve(filesystem);
        });

        return deferred.promise;
    }
})

    .factory('DBackUp', function (FileService, $q, $http) {
    var backUpInterval;

    //grab all db table names
    function getTableNames() {
        var db = window.openDatabase("GradeBlade", "", "GradeBlade", 10000000);
        var deferred = $q.defer();

        db.transaction(function (tx) {
            tx.executeSql("SELECT name FROM sqlite_master WHERE type='table'", [], function (tx, result) {
                if (result) {
                    //here are no your tables currently
                    var tablenames = [];
                    for (var i = 1; i < result.rows.length; i++) {
                        var rowobj = result.rows.item(i);
                        tablenames.push(rowobj.name);
                    }
                    deferred.resolve(tablenames);
                } else {
                    deferred.reject({
                        "error": "no tables"
                    });
                }
            }, function (tx, error) {
                deferred.reject(error);
            });
        }, function (tx, error) {
            deferred.reject(error);
        });

        return deferred.promise;
    }

    function iterateThroughTables() {
        var db = window.openDatabase("GradeBlade", "", "GradeBlade", 10000000);
        var deferred = $q.defer();

        getTableNames().then(function (tables) {
            var promises = [];

            //collect the promises
            for (var table in tables) {
                promises.push(grabTableInfo(tables[table], db));
            }

            //resolve them all
            $q.all(promises).then(function (data) {
                var dataString = "[";
                var counter = 1;
                var length = data.length;
                data.forEach(function (data) {
                    if (counter == length) {
                        dataString += data;
                    } else {
                        dataString += data + ',';
                    }

                    counter++;
                });
                dataString += "]";

                deferred.resolve(dataString);
            }, function (fail) {
                console.log(fail);
            });

        }, function (fail) {
            console.log(fail);
            deferred.reject([]);
        });

        return deferred.promise;
    }

    function grabTableInfo(name, db, Settings) {
        var deferred = $q.defer();
        db.transaction(function (tx) {
            tx.executeSql('SELECT * FROM ' + name, [], function (t, r) {
                if (t) {
                    var needCommas;
                    var tag = '{"' + name + '":[';
                    if (r.rows.length > 1) {
                        needCommas = true;
                    } else {
                        needCommas = false;
                    }
                    for (var i = 0; i < r.rows.length; i++) {
                        var rowobj = r.rows.item(i);
                        var data = rowobj.data;
                        if (data) {
                            var parsed = JSON.parse(data);
                            var newobj = {};
                            newobj.name = rowobj.name;
                            newobj.weight = rowobj.weight;
                            newobj.earned = rowobj.earned;
                            newobj.total = rowobj.total;
                            newobj.data = parsed;
                            tag = tag + angular.toJson(newobj);
                            if (needCommas && (i != (r.rows.length - 1))) {
                                tag = tag + ',';
                            }
                        } else {
                            tag = tag + angular.toJson(rowobj);
                            if (needCommas && (i != (r.rows.length - 1))) {
                                tag = tag + ',';
                            }
                        }
                    }
                    tag = tag + ']}';
                    //console.log(tag);

                    deferred.resolve(tag);
                } else {
                    deferred.reject({
                        "message": "had no data in it...weird"
                    });
                }
            }, function (tx, error) {
                deferred.reject(error);
            });
        }, function (tx, error) {
            deferred.reject(error);
        });
        return deferred.promise;
    }

    return {
        turnOnBackUps: function (toggle) {
            var parent = this;
            if (toggle) {
                console.log('starting back ups');
                backUpInterval = setInterval(function () {
                    parent.createBackUp()
                }, 300000);
            } else {
                console.log('stopping back ups');
                clearInterval(backUpInterval);
            }
        },
        createBackUp: function () {
            FileService.checkDir('GradeBlade').then(function () {
                FileService.checkFile('GradeBlade', 'dbbackup.json').then(function () {
                    //start backup
                    console.log('back file existed');
                    iterateThroughTables().then(function (data) {
                        //this is where we are gonna write to the backup file for each 'data'
                        //and then resolve so we return success back to createBackUp
                        FileService.writeFile('GradeBlade', 'dbbackup.json').then(function (writer) {
                            writer.write(data);
                            writer.onwriteend = function (evt) {
                                console.log('finished writing to file');
                            }
                        });
                        console.log(data);
                    }, function () {
                        console.log('it all just failed');
                    });
                }, function (fail) {
                    //don't exist so make it real quick
                    FileService.createFile('GradeBlade', 'dbbackup.json').then(function () {
                        console.log('back up file did not exist yet so we made it');
                        iterateThroughTables().then(function (data) {
                            //this is where we are gonna write to the backup file for each 'data'
                            //and then resolve so we return success back to createBackUp
                            FileService.writeFile('GradeBlade', 'dbbackup.json').then(function (writer) {
                                writer.write(data);
                                writer.onwriteend = function (evt) {
                                    console.log('done writing');
                                }
                            });
                            //console.log(data);
                        }, function (fail) {
                            console.log('failll');
                        });
                    });
                });
            }, function (fail) {

            });
        },
        runRestore: function () {
            FileService.readFile('GradeBlade', 'dbbackup.json').then(function (data) {
                var info = JSON.parse(data);
                //loop through table objects in data
                for (var key in info) {
                    //get the table name from this object
                    var table = info[key];
                    for (var name in table) {
                        //grab the table data
                        //grab the table name
                        var tableName = name;
                        var tableData = table[name];
                        console.log(tableName + ':' + JSON.stringify(tableData));
                    }
                }
            }, function (fail) {
                console.log(fail);
            });
        }
    }

})

    .factory('IAP', function () {
    var product;
    //class methods
    return {
        load: function () {
            var self = this;
            if (!window.store) {
                console.log("In-App Purchases not available");
                return;
            }

            // Enable maximum logging level
            store.verbosity = store.DEBUG;

            //register stuff
            store.register({
                'id': 'panda4man.gradeblade.noAds',
                    'alias': 'noAds',
                    'type': store.NON_CONSUMABLE
            });


            // When purchase of the full version is approved,
            // show some logs and finish the transaction.
            store.when("noAds").approved(function (order) {
                console.log('You just unlocked the FULL VERSION!');
                order.finish();
            });

            store.when('noAds').owned(function (p) {
                console.log('now we own it');
            });

            // Log all errors
            store.error(function (error) {
                console.log('ERROR ' + error.code + ': ' + error.message);
            });

            store.ready(function () {
                console.log('ready');
            });

            store.refresh();
        },

        setIAP: function () {
            var p = store.get('noAds');
            console.log('IT UPDATED PEOPLE!!\n' + JSON.stringify(p));
            product = p;
        },

        getProduct: function () {
            return product;
        },

        startWatch: function () {
            var self = this;
            console.log('start watching');
            store.when("noAds").updated(self.setIAP());
        },

        stopWatch: function () {
            var self = this;
            console.log('stop watching');
            store.off(self.setIAP());
        },

        buy: function (id) {
            store.order(id);
        }
        /*
		load: function () {
			if (!window.storekit) {
				console.log("In-App Purchases not available");
				return;
			}
 
			// Initialize
			storekit.init({
				debug:    true, // Enable IAP messages on the console
				noAutoFinish: true,
				ready:    this.onReady,
				purchase: this.onPurchase,
				restore:  this.onRestore,
				error:    this.onError
			});
		},
		onReady: function () {
			// Once setup is done, load all product data.
			storekit.load(list, function (products, invalidIds) {
				productList = products;
				loaded = true;
				for (var i = 0; i < invalidIds.length; ++i) {
					console.log("Error: could not load " + invalidIds[i]);
				}
			});
		},
		onPurchase: function (transactionId, productId) {
			storekit.finish(productId);
			console.log('WE ARE PURCHASING: ' + transactionId + ' ' + productId);
		},
		onRestore: function (transactionId, productId, transactionReceipt) {
		
		},
		restore: function () {
			console.log('in restore');
			storekit.restore();
		},
		onError: function (errorCode, errorMessage) {
			console.log('Error: ' + errorMessage);
		},
		list: function () {
			if(loaded){
				return productList;
			} else {
				console.log('No products!');
				return [];
			}
		},
		buy: function (productId) {
			storekit.purchase(productId, 1);
		},
		onBuy: function () {
			console.log('you bought stuff');
		}
		*/
    }
});

function nullHandler() {};

function errorHandler(transaction, error) {
    console.log('Error: ' + error.message + ' code: ' + error.code);
    /*
    navigator.notification.alert(
        'Error: ' + error.message + ' code: ' + error.code,
    null,
        'Error');
*/

}